# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountConversations(BaseModel):
    count_conversations: Optional["CountConversationsCountConversations"] = Field(
        alias="countConversations"
    )


class CountConversationsCountConversations(BaseModel):
    count: Optional[Any]


CountConversations.model_rebuild()
