# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalDrugClass(BaseModel):
    create_medical_drug_class: Optional[
        "CreateMedicalDrugClassCreateMedicalDrugClass"
    ] = Field(alias="createMedicalDrugClass")


class CreateMedicalDrugClassCreateMedicalDrugClass(BaseModel):
    id: str
    name: str


CreateMedicalDrugClass.model_rebuild()
