# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSharePointConsentUri(BaseModel):
    share_point_consent_uri: Optional["GetSharePointConsentUriSharePointConsentUri"] = (
        Field(alias="sharePointConsentUri")
    )


class GetSharePointConsentUriSharePointConsentUri(BaseModel):
    uri: Optional[Any]


GetSharePointConsentUri.model_rebuild()
