# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QuerySharePointFolders(BaseModel):
    share_point_folders: Optional["QuerySharePointFoldersSharePointFolders"] = Field(
        alias="sharePointFolders"
    )


class QuerySharePointFoldersSharePointFolders(BaseModel):
    account_name: Optional[str] = Field(alias="accountName")
    results: Optional[List[Optional["QuerySharePointFoldersSharePointFoldersResults"]]]


class QuerySharePointFoldersSharePointFoldersResults(BaseModel):
    folder_name: Optional[str] = Field(alias="folderName")
    folder_id: Optional[str] = Field(alias="folderId")


QuerySharePointFolders.model_rebuild()
QuerySharePointFoldersSharePointFolders.model_rebuild()
