# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateEvent(BaseModel):
    update_event: Optional["UpdateEventUpdateEvent"] = Field(alias="updateEvent")


class UpdateEventUpdateEvent(BaseModel):
    id: str
    name: str


UpdateEvent.model_rebuild()
