# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateProduct(BaseModel):
    update_product: Optional["UpdateProductUpdateProduct"] = Field(
        alias="updateProduct"
    )


class UpdateProductUpdateProduct(BaseModel):
    id: str
    name: str


UpdateProduct.model_rebuild()
