# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteRepos(BaseModel):
    delete_repos: Optional[List[Optional["DeleteReposDeleteRepos"]]] = Field(
        alias="deleteRepos"
    )


class DeleteReposDeleteRepos(BaseModel):
    id: str
    state: EntityState


DeleteRepos.model_rebuild()
